@@ -10,14 +10,17 @@ sub new {
     my $class = shift;
     my %args = @_;
     my $filename = File::Temp::tmpnam();
+
+    my $init = Storable::dclone({
+        array  => $args{builder}->{Test_Results},
+        scalar => $args{builder}->{Curr_Test},
+    });
+
     my $self = bless {callback_on_open => $args{cb}, filename => $filename, lock => 0, pid => $$, ppid => $$}, $class;
     $self->open();
 
     # initialize
-    Storable::nstore_fd(+{
-        array => [],
-        scalar => 0,
-    }, $self->{fh});
+    Storable::nstore_fd($init, $self->{fh}) or die "Cannot write initialize data to $filename";
 
     return $self;
 }
@@ -75,7 +78,7 @@ sub set_nolock {
 
     truncate $self->{fh}, 0;
     seek $self->{fh}, 0, SEEK_SET or die $!;
-    Storable::nstore_fd($dat => $self->{fh});
+    Storable::nstore_fd($dat => $self->{fh}) or die "Cannot store data to $self->{filename}";
 }
 
 sub lock_cb {
